pub struct DateTime(/* private fields */);Expand description
DateTime is a wrapper around the epoch time as i64. This type also functions as a wrapper around the time package which offers some of the more useful datetime functionality that is required in the schedule module.
Implementations